TBriDGE Documentation — TBriDGE documentation

# TBriDGE Documentation

- Setting up TBriDGE Config
- Simulating Galaxies
- Making a Simulation Pipeline
- tbridge package
  - Subpackages
  - Submodules
  - tbridge.binning module
  - tbridge.config module
  - tbridge.data module
  - tbridge.densities module
  - tbridge.extraction module
  - tbridge.masking module
  - tbridge.medians module
  - tbridge.modelling module
  - tbridge.profiles module
  - tbridge.sims module
  - Module contents

Note

TBriDGE is stil a work in progress and many methods, though feature complete and should be completely free of bugs, are in need of continued optimization.